#!/usr/bin/env bash

MODE=$1

PWD=$(cd `dirname $0`; pwd)
REGISTRY=xuper

IMAGES=(
traefik:v2.6
$REGISTRY/mysql:5.7.26
$REGISTRY/elasticsearch:5.6.13
$REGISTRY/xbaas-xcompiler:latest
$REGISTRY/xchain:v5.2.0
$REGISTRY/xbaas-core:latest
$REGISTRY/xbaas-explorer:latest
)

function env(){
    # docker 是否安装
    if ! docker -v; then
      print_red "未发现docker,请先安装docker"
      exit 1
    fi

    # docker-compose 是否安装
    if ! docker-compose -v; then
      print_red "未发现docker-compose,请先安装docker-compose"
      exit 1
    fi

    # 创建docker network
    network=$(docker network ls | grep baas_xuperchain) || true
    if [[ "$network" == "" ]]; then
      docker network create -d bridge --subnet=172.31.1.0/24 baas_xuperchain
    fi

    # 拉取服务镜像
    pullImages
}

function up() {
    env

    set -e

    echo "启动baas相关服务..."
    REGISTRY=$REGISTRY PWD=$PWD docker-compose -f local-chain.yaml -f docker-compose.yaml up -d
    echo "启动baas相关服务成功，请访问http://127.0.0.1:80"
}

function pullImages(){
    for image in ${IMAGES[@]};
    do
        docker pull $image
    done
}

function down() {
    echo "停止baas相关服务..."
    REGISTRY=$REGISTRY docker-compose -f docker-compose.yaml -f local-chain.yaml down

     echo "删除docker网络 baas_xuperchain"
     docker network rm baas_xuperchain 2> /dev/null

    network=$(docker network ls --filter name=baas_xuperchain|grep baas_xuperchain)
    if [ "$network" ]; then
         containers=$(docker network inspect --format '{{range $cid,$v := .Containers}}{{printf "%s\n" $cid}}{{end}}' baas_xuperchain)
         if [ "$containers" ]; then
            docker rm -f $containers
         fi
    fi

    echo "停止baas相关服务成功"
}


function printHelp() {
  echo "Usage: "
  echo "  baas.sh <mode>"
  echo "    <mode> - one of 'up', 'down', 'restart'"
  echo "      - 'up' - start up baas servers"
  echo "      - 'down' - stop baas servers"
  echo "      - 'restart' - down & up"
  echo "  baas.sh -h (print this message)"
  echo
  echo  "start up baas. e.g.:"
  echo
  echo "	baas.sh up"
  echo
  echo "Taking all defaults:"
  echo "	baas.sh up"
  echo "	baas.sh down"
  echo "	baas.sh restart"
}

if [ "${MODE}" == "up" ]; then
  up
elif [ "${MODE}" == "down" ]; then
  down
elif [ "${MODE}" == "restart" ]; then
  down
  up
else
  printHelp
  exit 1
fi
